@@ -31,7 +31,11 @@ import pan.config
 
 
 def main():
-    signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+    try:
+        signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+    except AttributeError:
+        # Windows
+        pass
 
     options = parse_opts()
 
