@@ -312,7 +312,7 @@ def main():
             print_response(xapi, options)
 
     except pan.xapi.PanXapiError as msg:
-        print_status(xapi, action, msg)
+        print_status(xapi, action, str(msg))
         print_response(xapi, options)
         sys.exit(1)
 
@@ -643,19 +643,22 @@ def print_status(xapi, action, exception_msg=None):
         code = ''
     if xapi.status is not None:
         print(': %s%s' % (xapi.status, code), end='', file=sys.stderr)
-    if exception_msg is not None and str(exception_msg):
-        print(': "%s"' % exception_msg, end='', file=sys.stderr)
+    if exception_msg is not None and exception_msg:
+        print(': "%s"' % exception_msg.rstrip(), end='', file=sys.stderr)
     elif xapi.status_detail is not None:
-        print(': "%s"' % xapi.status_detail, end='', file=sys.stderr)
+        print(': "%s"' % xapi.status_detail.rstrip(), end='', file=sys.stderr)
     print(file=sys.stderr)
 
 
 def xml_python(xapi, result=False):
+    xpath = None
     if result:
         if (xapi.element_result is None or
                 not len(xapi.element_result)):
             return None
-        elem = list(xapi.element_result)[0]
+        elem = xapi.element_result
+        # select all child elements
+        xpath = '*'
     else:
         if xapi.element_root is None:
             return None
@@ -667,7 +670,7 @@ def xml_python(xapi, result=False):
         print('pan.config.PanConfigError:', msg, file=sys.stderr)
         sys.exit(1)
 
-    d = conf.python()
+    d = conf.python(xpath)
     return d
 
 
@@ -678,7 +681,7 @@ def print_response(xapi, options):
         else:
             s = xapi.xml_root()
         if s is not None:
-            print(s)
+            print(s.lstrip('\r\n').rstrip())
 
     if options['print_python'] or options['print_json']:
         d = xml_python(xapi, options['print_result'])
