@@ -144,8 +144,7 @@ class PanConfig:
         d = {}
         if len(nodes) > 1:
             for elem in nodes:
-                d[elem.tag] = {}
-                self.__serialize_py(elem, d[elem.tag])
+                self.__serialize_py(elem, d)
         else:
             self.__serialize_py(nodes[0], d)
 
@@ -499,7 +498,7 @@ class PanConfig:
             elif self.config_version() in ['6.0.0']:
                 xpaths_panos = xpaths_panos_6_0
                 xpaths_panorama = xpaths_panorama_6_0
-            elif self.config_version() in ['6.0.1']:
+            elif self.config_version() in ['6.1.0']:
                 xpaths_panos = xpaths_panos_6_0
                 xpaths_panorama = xpaths_panorama_6_1
 
