@@ -51,7 +51,7 @@ class PanRc:
                  init_panrc=None,
                  search_path=_search_path,
                  filename=_filename):
-        self.log = logging.getLogger(__name__).log
+        self._log = logging.getLogger(__name__).log
         self.tag = tag
         self.init_panrc = init_panrc
         self.search_path = search_path
@@ -65,7 +65,7 @@ class PanRc:
 
         self.__parse_path()
         s = pprint.pformat(self.panrc, indent=_indent)
-        self.log(DEBUG1, 'panrc: %s', s)
+        self._log(DEBUG1, 'panrc: %s', s)
 
     def __parse_path(self):
         panrcs = []
@@ -75,7 +75,7 @@ class PanRc:
                 if self.init_panrc:
                     s = pprint.pformat(self.init_panrc,
                                        indent=_indent)
-                    self.log(DEBUG2, '__parse_path: __init__(): %s', s)
+                    self._log(DEBUG2, '__parse_path: __init__(): %s', s)
                     panrcs.append(self.init_panrc)
             else:
                 path = os.path.expanduser(basename)  # ~, ~user
@@ -84,7 +84,7 @@ class PanRc:
                 d = self.__parse_file(path)
                 if d:
                     s = pprint.pformat(d, indent=_indent)
-                    self.log(DEBUG2, '__parse_path: %s: %s', path, s)
+                    self._log(DEBUG2, '__parse_path: %s: %s', path, s)
                     panrcs.append(d)
 
         if panrcs:
@@ -94,7 +94,7 @@ class PanRc:
         try:
             f = open(path, 'r')
         except IOError as msg:
-            self.log(DEBUG3, 'open %s: %s', path, msg)
+            self._log(DEBUG3, 'open %s: %s', path, msg)
             return None
 
         panrc = {}
@@ -119,7 +119,7 @@ class PanRc:
     def __merge_panrcs(self, panrcs):
         panrcs.reverse()
         s = pprint.pformat(panrcs, indent=_indent)
-        self.log(DEBUG2, 'panrcs: %s', s)
+        self._log(DEBUG2, 'panrcs: %s', s)
 
         for panrc in panrcs:
             for key in panrc.keys():
